// Copyright 2009 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

// +build ignore

/*

6a is a version of the Plan 9 assembler.  The original is documented at

	http://plan9.bell-labs.com/magic/man2html/1/8a

Its target architecture is the x86-64, referred to by these tools as amd64.

*/
package main
